@@ -1,6 +1,7 @@
-import typer
 from click.shell_completion import CompletionItem
 
+import typer_cloup as typer
+
 valid_completion_items = [
     ("Camila", "The reader of books."),
     ("Carlos", "The writer of scripts."),
