@@ -1,9 +1,10 @@
 from typing import List
 
 import click
-import typer
 from click.shell_completion import CompletionItem
 
+import typer_cloup as typer
+
 valid_completion_items = [
     ("Camila", "The reader of books."),
     ("Carlos", "The writer of scripts."),
