@@ -3,7 +3,7 @@ import typer_cloup as typer
 app = typer.Typer()
 
 users_app = typer.Typer()
-app.add_typer(users_app, name="users", help="Manage users in the app.")
+app.add_sub(users_app, name="users", help="Manage users in the app.")
 
 
 @users_app.command()
