@@ -1,9 +1,8 @@
 import os
 import subprocess
 
-from typer.testing import CliRunner
-
 from docs_src.options_autocompletion import tutorial008 as mod
+from typer_cloup.testing import CliRunner
 
 runner = CliRunner()
 
