@@ -1,9 +1,8 @@
 import subprocess
 
-import typer
-from typer.testing import CliRunner
-
+import typer_cloup as typer
 from docs_src.parameter_types.number import tutorial002 as mod
+from typer_cloup.testing import CliRunner
 
 runner = CliRunner()
 
