@@ -55,8 +55,8 @@ if TYPE_CHECKING:  # pragma: no cover
 
 def get_install_completion_arguments() -> Tuple[click.Parameter, click.Parameter]:
     install_param, show_param = get_completion_inspect_parameters()
-    click_install_param, _ = get_cloup_param(install_param)
-    click_show_param, _ = get_cloup_param(show_param)
+    click_install_param, _ = get_click_param(install_param)
+    click_show_param, _ = get_click_param(show_param)
     return click_install_param, click_show_param
 
 
@@ -98,7 +98,6 @@ class Typer:
             name=name,
             cls=cls,
             invoke_without_command=invoke_without_command,
-            no_args_is_help=no_args_is_help,
             subcommand_metavar=subcommand_metavar,
             chain=chain,
             result_callback=result_callback,
@@ -115,6 +114,7 @@ class Typer:
             short_help=short_help,
             options_metavar=options_metavar,
             add_help_option=add_help_option,
+            no_args_is_help=no_args_is_help,
             hidden=hidden,
             deprecated=deprecated,
             align_option_groups=align_option_groups,
@@ -130,7 +130,6 @@ class Typer:
         *,
         cls: Optional[Type[TyperGroup]] = Default(None),
         invoke_without_command: bool = Default(False),
-        no_args_is_help: bool = Default(False),
         subcommand_metavar: Optional[str] = Default(None),
         chain: bool = Default(False),
         result_callback: Optional[Callable[..., Any]] = Default(None),
@@ -144,6 +143,7 @@ class Typer:
         short_help: Optional[str] = Default(None),
         options_metavar: str = Default("[OPTIONS]"),
         add_help_option: bool = Default(True),
+        no_args_is_help: bool = Default(False),
         hidden: bool = Default(False),
         deprecated: bool = Default(False),
         align_option_groups: Optional[bool] = Default(None),
@@ -155,7 +155,6 @@ class Typer:
                 name=name,
                 cls=cls,
                 invoke_without_command=invoke_without_command,
-                no_args_is_help=no_args_is_help,
                 subcommand_metavar=subcommand_metavar,
                 chain=chain,
                 result_callback=result_callback,
@@ -169,6 +168,7 @@ class Typer:
                 short_help=short_help,
                 options_metavar=options_metavar,
                 add_help_option=add_help_option,
+                no_args_is_help=no_args_is_help,
                 hidden=hidden,
                 deprecated=deprecated,
                 align_option_groups=align_option_groups,
@@ -184,10 +184,10 @@ class Typer:
         self,
         name: Optional[str] = None,
         *,
+        cls: Optional[Type[TyperCommand]] = None,
         aliases: Optional[Iterable[str]] = None,
         section: Optional[cloup.Section] = None,
         constraints: Sequence["BoundConstraintSpec"] = (),
-        cls: Optional[Type[TyperCommand]] = None,
         context_settings: Optional[Dict[Any, Any]] = None,
         formatter_settings: Optional[Dict[str, Any]] = None,
         help: Optional[str] = None,
@@ -207,10 +207,10 @@ class Typer:
         def decorator(f: CommandFunctionType) -> CommandFunctionType:
             info = CommandInfo(
                 name=name,
+                cls=cls,
                 aliases=aliases,
                 section=section,
                 constraints=constraints,
-                cls=cls,
                 context_settings=context_settings,
                 formatter_settings=formatter_settings,
                 callback=f,
@@ -231,14 +231,13 @@ class Typer:
 
         return decorator
 
-    def add_typer(
+    def add_sub(
         self,
         typer_instance: "Typer",
         *,
         name: Optional[str] = Default(None),
         cls: Optional[Type[TyperGroup]] = Default(None),
         invoke_without_command: bool = Default(False),
-        no_args_is_help: bool = Default(False),
         subcommand_metavar: Optional[str] = Default(None),
         chain: bool = Default(False),
         result_callback: Optional[Callable[..., Any]] = Default(None),
@@ -254,6 +253,7 @@ class Typer:
         short_help: Optional[str] = Default(None),
         options_metavar: str = Default("[OPTIONS]"),
         add_help_option: bool = Default(True),
+        no_args_is_help: bool = Default(False),
         hidden: bool = Default(False),
         deprecated: bool = Default(False),
         align_option_groups: Optional[bool] = Default(None),
@@ -404,7 +404,7 @@ def get_command(typer_instance: Typer) -> click.Command:
 
 def get_group_name(typer_info: TyperInfo) -> Optional[str]:
     if typer_info.callback:
-        # Priority 1: Callback passed in app.add_typer()
+        # Priority 1: Callback passed in app.add_sub()
         return get_command_name(typer_info.callback.__name__)
     if typer_info.typer_instance:
         registered_callback = typer_info.typer_instance.registered_callback
@@ -418,7 +418,7 @@ def get_group_name(typer_info: TyperInfo) -> Optional[str]:
 
 
 def solve_typer_info_help(typer_info: TyperInfo) -> str:
-    # Priority 1: Explicit value was set in app.add_typer()
+    # Priority 1: Explicit value was set in app.add_sub()
     if not isinstance(typer_info.help, DefaultPlaceholder):
         return inspect.cleandoc(typer_info.help or "")
     # Priority 2: Explicit value was set in sub_app.callback()
@@ -435,7 +435,7 @@ def solve_typer_info_help(typer_info: TyperInfo) -> str:
             return inspect.cleandoc(instance_help or "")
     except AttributeError:
         pass
-    # Priority 4: Implicit inference from callback docstring in app.add_typer()
+    # Priority 4: Implicit inference from callback docstring in app.add_sub()
     if typer_info.callback:
         doc = inspect.getdoc(typer_info.callback)
         if doc:
@@ -466,7 +466,7 @@ def solve_typer_info_defaults(typer_info: TyperInfo) -> TyperInfo:
     values: Dict[str, Any] = {}
     name = None
     for name, value in typer_info.__dict__.items():
-        # Priority 1: Value was set in app.add_typer()
+        # Priority 1: Value was set in app.add_sub()
         if not isinstance(value, DefaultPlaceholder):
             values[name] = value
             continue
@@ -546,7 +546,6 @@ def get_group_from_info(group_info: TyperInfo) -> click.Group:
         callback=get_callback(
             callback=solved_info.callback,
             params=params,
-            convertors=convertors,
             context_param_name=context_param_name,
         ),
         params=params,
@@ -575,7 +574,7 @@ def get_command_name(name: str) -> str:
 
 def get_params_convertors_ctx_param_name_from_function(
     callback: Optional[Callable[..., Any]]
-) -> Tuple[List[Union[cloup.Argument, cloup.Option]], Dict[str, Any], Optional[str]]:
+) -> Tuple[List[Union[click.Argument, click.Option]], Dict[str, Any], Optional[str]]:
     params = {}
     convertors = {}
     context_param_name = None
@@ -585,7 +584,7 @@ def get_params_convertors_ctx_param_name_from_function(
             if lenient_issubclass(param.annotation, click.Context):
                 context_param_name = param_name
                 continue
-            click_param, convertor = get_cloup_param(param)
+            click_param, convertor = get_click_param(param)
             if convertor:
                 convertors[param_name] = convertor
             params[param_name] = click_param
@@ -643,7 +642,6 @@ def get_command_from_info(command_info: CommandInfo) -> click.Command:
         callback=get_callback(
             callback=command_info.callback,
             params=params,
-            convertors=convertors,
             context_param_name=context_param_name,
         ),
         params=params,
@@ -718,7 +716,6 @@ def get_callback(
     *,
     callback: Optional[Callable[..., Any]] = None,
     params: Sequence[click.Parameter] = [],
-    convertors: Dict[str, Callable[[str], Any]] = {},
     context_param_name: Optional[str] = None,
 ) -> Optional[Callable[..., Any]]:
     if not callback:
@@ -733,10 +730,7 @@ def get_callback(
 
     def wrapper(**kwargs: Any) -> Any:
         for k, v in kwargs.items():
-            if k in convertors:
-                use_params[k] = convertors[k](v)
-            else:
-                use_params[k] = v
+            use_params[k] = v
         if context_param_name:
             use_params[context_param_name] = click.get_current_context()
         return callback(**use_params)  # type: ignore
@@ -853,9 +847,9 @@ def lenient_issubclass(
     return isinstance(cls, type) and issubclass(cls, class_or_tuple)
 
 
-def get_cloup_param(
+def get_click_param(
     param: ParamMeta,
-) -> Tuple[Union[cloup.Argument, cloup.Option], Any]:
+) -> Tuple[Union[click.Argument, click.Option], Any]:
     # First, find out what will be:
     # * ParamInfo (ArgumentInfo or OptionInfo)
     # * default_value
@@ -956,6 +950,7 @@ def get_cloup_param(
                 count=parameter_info.count,
                 allow_from_autoenv=parameter_info.allow_from_autoenv,
                 type=parameter_type,
+                convertor=convertor,
                 help=parameter_info.help,
                 hidden=parameter_info.hidden,
                 show_choices=parameter_info.show_choices,
@@ -986,6 +981,7 @@ def get_cloup_param(
                 # Argument
                 param_decls=param_decls,
                 type=parameter_type,
+                convertor=convertor,
                 required=required,
                 nargs=nargs,
                 # TyperArgument
